@@ -79,8 +79,8 @@ def test_check_access_true():
     sdk = IntelliOpsOpenFgaSDK()
     sdk.http_client = DummyHttpClient()
     model = CheckAccessModel(
-        user_uid="t417ce8a_Confluence_e4448be1-8022-43a2-b234-e467842aac60_5b70c8b80fd0ac05d389f5e9",
-        object_id="t417ce8a_Confluence_e4448be1-8022-43a2-b234-e467842aac60_190480451"
+        intelliopsUserUId="t417ce8a_Confluence_e4448be1-8022-43a2-b234-e467842aac60_5b70c8b80fd0ac05d389f5e9",
+        fgaObjectId="t417ce8a_Confluence_e4448be1-8022-43a2-b234-e467842aac60_190480451"
     )
     assert sdk.check_access(model) is True
 
@@ -89,8 +89,8 @@ def test_check_access_false():
     sdk = IntelliOpsOpenFgaSDK()
     sdk.http_client = DummyHttpClient()
     model = CheckAccessModel(
-        user_uid="t417ce8a_Confluence_e4448be1-8022-43a2-b234-e467842aac60_5b70c8b80fd0ac05d389f5e9",
-        object_id="t417ce8a_Confluence_e4448be1-8022-43a2-b234-e467842aac60_19048045"
+        intelliopsUserUId="t417ce8a_Confluence_e4448be1-8022-43a2-b234-e467842aac60_5b70c8b80fd0ac05d389f5e9",
+        fgaObjectId="t417ce8a_Confluence_e4448be1-8022-43a2-b234-e467842aac60_19048045"
     )
     assert sdk.check_access(model) is False
 
@@ -196,8 +196,8 @@ def test_async_check_access_true():
     sdk = IntelliOpsOpenFgaSDK()
     sdk.http_client = DummyAsyncHttpClient()
     model = CheckAccessModel(
-        user_uid="t417ce8a_Confluence_e4448be1-8022-43a2-b234-e467842aac60_5b70c8b80fd0ac05d389f5e9",
-        object_id="t417ce8a_Confluence_e4448be1-8022-43a2-b234-e467842aac60_190480451"
+        intelliopsUserUId="t417ce8a_Confluence_e4448be1-8022-43a2-b234-e467842aac60_5b70c8b80fd0ac05d389f5e9",
+        fgaObjectId="t417ce8a_Confluence_e4448be1-8022-43a2-b234-e467842aac60_190480451"
     )
     result = asyncio.run(sdk.async_check_access(model))
     assert result is True
@@ -211,8 +211,8 @@ def test_async_check_access_false():
     sdk = IntelliOpsOpenFgaSDK()
     sdk.http_client = DummyAsyncHttpClient()
     model = CheckAccessModel(
-        user_uid="t417ce8a_Confluence_e4448be1-8022-43a2-b234-e467842aac60_5b70c8b80fd0ac05d389f5e9",
-        object_id="t417ce8a_Confluence_e4448be1-8022-43a2-b234-e467842aac60_19048045"
+        intelliopsUserUId="t417ce8a_Confluence_e4448be1-8022-43a2-b234-e467842aac60_5b70c8b80fd0ac05d389f5e9",
+        fgaObjectId="t417ce8a_Confluence_e4448be1-8022-43a2-b234-e467842aac60_19048045"
     )
     result = asyncio.run(sdk.async_check_access(model))
     assert result is False
@@ -235,8 +235,8 @@ def test_check_multi_access():
     sdk = IntelliOpsOpenFgaSDK()
     sdk.http_client = DummyHttpClientMulti()
     model = CheckMultipleAccessModel(
-        user_uid="t417ce8a_Confluence_e4448be1-8022-43a2-b234-e467842aac60_5b70c8b80fd0ac05d389f5e9",
-        object_ids=[
+        intelliopsUserUId="t417ce8a_Confluence_e4448be1-8022-43a2-b234-e467842aac60_5b70c8b80fd0ac05d389f5e9",
+        fgaObjectIds=[
             "t417ce8a_Confluence_e4448be1-8022-43a2-b234-e467842aac60_550568177",
             "t417ce8a_Confluence_e4448be1-8022-43a2-b234-e467842aac60_669876453",
             "t417ce8a_Confluence_e4448be1-8022-43a2-b234-e467842aac60_190480451"
@@ -268,8 +268,8 @@ def test_async_check_multi_access():
     sdk = IntelliOpsOpenFgaSDK()
     sdk.http_client = DummyAsyncHttpClientMulti()
     model = CheckMultipleAccessModel(
-        user_uid="t417ce8a_Confluence_e4448be1-8022-43a2-b234-e467842aac60_5b70c8b80fd0ac05d389f5e9",
-        object_ids=[
+        intelliopsUserUId="t417ce8a_Confluence_e4448be1-8022-43a2-b234-e467842aac60_5b70c8b80fd0ac05d389f5e9",
+        fgaObjectIds=[
             "t417ce8a_Confluence_e4448be1-8022-43a2-b234-e467842aac60_550568177",
             "t417ce8a_Confluence_e4448be1-8022-43a2-b234-e467842aac60_669876453",
             "t417ce8a_Confluence_e4448be1-8022-43a2-b234-e467842aac60_190480451"
